@@ -28,7 +28,99 @@ from .device import Device
 logger = logging.getLogger(__name__)
 
 
-class AbstractNode(PersistentObject):
+class NonExistingNode(PersistentObject):
+    """A kind of Null-object as it represents a non-existing Node. It's deriving from PersistentObject but is not meant to be
+    persisted. Instead, it's be created on the fly from the NodeManager if it doesn't have a reasonable node available.
+    It also works as some kind of minimal implementation so that specter doesn't fail gracefully.
+    """
+
+    @property
+    def info(self):
+        return {}
+
+    @property
+    def network_info(self):
+        return {}
+
+    @property
+    def uptime(self):
+        return -1
+
+    @property
+    def chain(self):
+        return None
+
+    @property
+    def bitcoin_core_version_raw(self):
+        return 9999999
+
+    def update_rpc(self):
+        pass
+
+    @property
+    def is_running(self):
+        return False
+
+    @property
+    def rpc(self):
+        return None
+
+    @property
+    def network_parameters(self):
+        """Needed for the derivation path in xpubs when adding a device."""
+        return get_network("main")
+
+    def check_blockheight(self):
+        """check_blockheight is a method which is probably deprecated.
+        It should return True if there are new blocks available since check_info has been called
+        (which updates the cached _info[] dict)
+        """
+        raise NotImplemented(
+            "A Node Implementation need to implement the check_blockheight method"
+        )
+
+    def is_device_supported(self, device_class_or_device_instance):
+        """Lets the node deactivate specific devices. The parameter could be a device or a device_type
+            You have to check yourself if overriding this method.
+        e.g.
+        if device_instance_or_device_class.__class__ == type:
+            device_class = device_instance_or_device_class
+        else:
+            device_class = device_instance_or_device_class.__class__
+        # example:
+        # if BitcoinCore == device_class:
+        #    return False
+        return True
+        """
+        return True
+
+    def node_info_template(self):
+        """This should return the path to a Info template as string"""
+        return "node/components/bitcoin_core_info.jinja"
+
+    def node_logo_template(self):
+        """This should return the path to a Logo template as string
+        The template should contain the logo independent from the
+        status of the node. It's used in the node-selector
+        """
+        return "includes/sidebar/components/node_logo.jinja"
+
+    def node_connection_template(self):
+        """This should return the path to a connection template as string"""
+        return "includes/sidebar/components/node_connection.jinja"
+
+    def delete_wallet_file(self, wallet) -> bool:
+        """Deleting the wallet file located on the node. This only works if the node is on the same machine as Specter.
+        Returns True if the wallet file could be deleted, otherwise returns False.
+
+        In the case of an Abtract Node, we consider that method as an edge-case anyway and we just return False here.
+        That is the normal usage if you don't have access to the internals of your Bitcoin Core.
+        Overwrite as necessary.
+        """
+        return False
+
+
+class AbstractNode(NonExistingNode):
     """This is a Node class worth deriving from. It tries to define as many attributes as possible which are needed but probably in a very
     inefficient way, e.g. without any caching. Feel free to improve that in subclasses and you might get inspired by existing sublasses
     """
@@ -112,10 +204,6 @@ class AbstractNode(PersistentObject):
 
     # ... and more derived properties which already calculate stuff based on those information
 
-    @property
-    def network_parameters(self):
-        return get_network(self.chain)
-
     @property
     def is_testnet(self):
         return is_testnet(self.chain)
@@ -128,14 +216,18 @@ class AbstractNode(PersistentObject):
         else:
             return True
 
+    @property
+    def network_parameters(self):
+        """Uses an RPC call since AbstractNode has no cache"""
+        if self.is_running:
+            return get_network(self.chain)
+        return get_network("main")
+
     def check_blockheight(self):
-        """check_blockheight is a method which is probably deprecated.
-        It should return True if there are new blocks available since check_info has been called
+        """Should return True if there are new blocks available since check_info has been called
         (which updates the cached _info[] dict)
         """
-        raise NotImplemented(
-            "A Node Implementation need to implement the check_blockheight method"
-        )
+        return self.info.get("blocks") != self.rpc.getblockcount()
 
     def is_device_supported(self, device_class_or_device_instance):
         """Lets the node deactivate specific devices. The parameter could be a device or a device_type
@@ -153,15 +245,15 @@ class AbstractNode(PersistentObject):
         return True
 
     def node_info_template(self):
-        """This should return the path to a Info template as string"""
+        """This should return the path to an info template as string"""
         return "node/components/bitcoin_core_info.jinja"
 
     def node_logo_template(self):
-        """This should return the path to a Logo template as string
+        """This should return the path to a logo template as string
         The template should contain the logo independent from the
-        status of the node. It's used in the node-selector
+        status of the node. It's used in the node selector.
         """
-        return "includes/sidebar/components/node_logo.jinja"
+        return "node/components/node_logo.jinja"
 
     def node_connection_template(self):
         """This should return the path to a connection template as string"""
@@ -180,11 +272,9 @@ class AbstractNode(PersistentObject):
 
 class Node(AbstractNode):
     """A Node represents the connection to a Bitcoin and/or Liquid (Full-) node.
-    It can be created via Constructor or from_json, and mainly it can give you A
-    RPC-object to use the API.
-    On top of the RPC-connection it manages the stability of the rpc. It will only
-    persist healthy connections.
-    One or many Nodes are managed via the NodeManager
+    It can be created via constructor or from json. It mainly gives you a
+    RPC object to use the JSON RPC API of the node. It also manages the stability of this connection. It will only
+    persist healthy connections. One or more Nodes are managed via the NodeManager
     """
 
     external_node = True
@@ -549,14 +639,6 @@ class Node(AbstractNode):
         self._info["utxorescan"] = None
         self.utxorescanwallet = None
 
-    def check_blockheight(self):
-        if not self.rpc:
-            # if the rpc interface cannot be found, then specter should check the rpc interface.
-            # Checking the rpc interface with self.node.update_rpc() in specter.check() is done
-            # if we return True here
-            return True
-        return self.info.get("blocks") != self.rpc.getblockcount()
-
     def is_liquid(self):
         return is_liquid(self.chain)
 
@@ -598,6 +680,10 @@ class Node(AbstractNode):
             logger.debug(f"Could not find any wallet file at: {path}")
         return wallet_file_removed
 
+    def no_tx_hint(self):
+        """Returns the path to a template with some basic html and and a hint text to be used in the Transactions tab if there are no transactions"""
+        return "node/components/no_tx_hint.jinja"
+
     @property
     def is_running(self):
         if self._network_info["version"] == 999999:
